[cig-commits] r22569 - in short/3D/PyLith/trunk: libsrc/pylith/faults libsrc/pylith/meshio libsrc/pylith/problems libsrc/pylith/topology modulesrc/topology unittests/libtests/topology

brad at geodynamics.org brad at geodynamics.org
Thu Jul 11 13:48:27 PDT 2013


Author: brad
Date: 2013-07-11 13:48:27 -0700 (Thu, 11 Jul 2013)
New Revision: 22569

Modified:
   short/3D/PyLith/trunk/libsrc/pylith/faults/FaultCohesiveDyn.cc
   short/3D/PyLith/trunk/libsrc/pylith/meshio/DataWriterHDF5.cc
   short/3D/PyLith/trunk/libsrc/pylith/meshio/DataWriterHDF5Ext.cc
   short/3D/PyLith/trunk/libsrc/pylith/meshio/OutputSolnPoints.cc
   short/3D/PyLith/trunk/libsrc/pylith/problems/Formulation.cc
   short/3D/PyLith/trunk/libsrc/pylith/problems/SolverLinear.cc
   short/3D/PyLith/trunk/libsrc/pylith/problems/SolverNonlinear.cc
   short/3D/PyLith/trunk/libsrc/pylith/topology/Field.cc
   short/3D/PyLith/trunk/libsrc/pylith/topology/Field.hh
   short/3D/PyLith/trunk/modulesrc/topology/Field.i
   short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldMesh.cc
   short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldMesh.hh
   short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldSubMesh.cc
   short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldSubMesh.hh
Log:
Updated Field method names. scatterSectionToVector -> scatterLobalToGlobal, scatterVectorToSection -> scatterGlobalToLocal.

Modified: short/3D/PyLith/trunk/libsrc/pylith/faults/FaultCohesiveDyn.cc
===================================================================
--- short/3D/PyLith/trunk/libsrc/pylith/faults/FaultCohesiveDyn.cc	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/libsrc/pylith/faults/FaultCohesiveDyn.cc	2013-07-11 20:48:27 UTC (rev 22569)
@@ -1903,7 +1903,7 @@
   residual.complete();
 
   // Update PetscVector view of field.
-  residual.scatterSectionToVector();
+  residual.scatterLocalToGlobal();
 
   PetscErrorCode err = 0;
   const PetscMat jacobianMat = _jacobian->matrix();
@@ -1914,7 +1914,7 @@
   err = KSPSolve(_ksp, residualVec, solutionVec);PYLITH_CHECK_ERROR(err);
 
   // Update section view of field.
-  solution.scatterVectorToSection();
+  solution.scatterGlobalToLocal();
 
 #if 0 // DEBUGGING
   residual.view("SENSITIVITY RESIDUAL");

Modified: short/3D/PyLith/trunk/libsrc/pylith/meshio/DataWriterHDF5.cc
===================================================================
--- short/3D/PyLith/trunk/libsrc/pylith/meshio/DataWriterHDF5.cc	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/libsrc/pylith/meshio/DataWriterHDF5.cc	2013-07-11 20:48:27 UTC (rev 22569)
@@ -123,7 +123,7 @@
     err = DMGetCoordinatesLocal(dmMesh, &coordinates);PYLITH_CHECK_ERROR(err);
     topology::Field coordinatesField(mesh, dmCoord, coordinates, metadata);
     coordinatesField.createScatterWithBC(mesh, "", 0, metadata.label.c_str());
-    coordinatesField.scatterSectionToVector(metadata.label.c_str());
+    coordinatesField.scatterLocalToGlobal(metadata.label.c_str());
     PetscVec coordVector = coordinatesField.vector(metadata.label.c_str());assert(coordVector);
     err = VecScale(coordVector, lengthScale);PYLITH_CHECK_ERROR(err);
     err = PetscViewerHDF5PushGroup(_viewer, "/geometry");PYLITH_CHECK_ERROR(err);
@@ -276,7 +276,7 @@
     const char* context  = DataWriter::_context.c_str();
 
     field.createScatterWithBC(mesh, "", 0, context);
-    field.scatterSectionToVector(context);
+    field.scatterLocalToGlobal(context);
     PetscVec vector = field.vector(context);assert(vector);
 
     if (_timesteps.find(field.label()) == _timesteps.end())
@@ -337,7 +337,7 @@
     PetscErrorCode err = 0;
 
     field.createScatterWithBC(field.mesh(), label ? label : "", labelId, context);
-    field.scatterSectionToVector(context);
+    field.scatterLocalToGlobal(context);
     PetscVec vector = field.vector(context);assert(vector);
 
     if (_timesteps.find(field.label()) == _timesteps.end())

Modified: short/3D/PyLith/trunk/libsrc/pylith/meshio/DataWriterHDF5Ext.cc
===================================================================
--- short/3D/PyLith/trunk/libsrc/pylith/meshio/DataWriterHDF5Ext.cc	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/libsrc/pylith/meshio/DataWriterHDF5Ext.cc	2013-07-11 20:48:27 UTC (rev 22569)
@@ -340,7 +340,7 @@
     err = PetscObjectGetComm((PetscObject) dmMesh, &comm);PYLITH_CHECK_ERROR(err);
     err = MPI_Comm_rank(comm, &commRank);PYLITH_CHECK_ERROR(err);
     field.createScatterWithBC(mesh, "", 0, context);
-    field.scatterSectionToVector(context);
+    field.scatterLocalToGlobal(context);
 
     PetscViewer binaryViewer;
 
@@ -479,7 +479,7 @@
     err = PetscObjectGetComm((PetscObject) dmMesh, &comm);PYLITH_CHECK_ERROR(err);
     err = MPI_Comm_rank(comm, &commRank);PYLITH_CHECK_ERROR(err);
     field.createScatterWithBC(field.mesh(), label ? label : "", labelId, context);
-    field.scatterSectionToVector(context);
+    field.scatterLocalToGlobal(context);
 
     PetscViewer binaryViewer;
 

Modified: short/3D/PyLith/trunk/libsrc/pylith/meshio/OutputSolnPoints.cc
===================================================================
--- short/3D/PyLith/trunk/libsrc/pylith/meshio/OutputSolnPoints.cc	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/libsrc/pylith/meshio/OutputSolnPoints.cc	2013-07-11 20:48:27 UTC (rev 22569)
@@ -267,7 +267,7 @@
   err = DMInterpolationSetDof(_interpolator, fiberDim);PYLITH_CHECK_ERROR(err);
   err = DMInterpolationEvaluate(_interpolator, dmMesh, field.localVector(), fieldInterpVec);PYLITH_CHECK_ERROR(err);
 
-  fieldInterp.scatterVectorToSection(context);
+  fieldInterp.scatterGlobalToLocal(context);
 
   OutputManager::appendVertexField(t, fieldInterp, *_pointsMesh);
 

Modified: short/3D/PyLith/trunk/libsrc/pylith/problems/Formulation.cc
===================================================================
--- short/3D/PyLith/trunk/libsrc/pylith/problems/Formulation.cc	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/libsrc/pylith/problems/Formulation.cc	2013-07-11 20:48:27 UTC (rev 22569)
@@ -200,7 +200,7 @@
   // Update section view of field.
   if (tmpSolutionVec) {
     topology::Field& solution = _fields->solution();
-    solution.scatterVectorToSection(*tmpSolutionVec);
+    solution.scatterGlobalToLocal(*tmpSolutionVec);
   } // if
 
   // Update rate fields (must be consistent with current solution).
@@ -223,9 +223,9 @@
 
   // Update PETSc view of residual
   if (tmpResidualVec)
-    residual.scatterSectionToVector(*tmpResidualVec);
+    residual.scatterLocalToGlobal(*tmpResidualVec);
   else
-    residual.scatterSectionToVector();
+    residual.scatterLocalToGlobal();
 
   // TODO: Move this to SolverLinear 
   if (tmpResidualVec)
@@ -247,7 +247,7 @@
   // Update section view of field.
   if (tmpSolutionVec) {
     topology::Field& solution = _fields->solution();
-    solution.scatterVectorToSection(*tmpSolutionVec);
+    solution.scatterGlobalToLocal(*tmpSolutionVec);
   } // if
 
   // Set jacobian to zero.
@@ -327,7 +327,7 @@
 
   // Update section view of field.
   if (tmpSolutionVec) {
-    solution.scatterVectorToSection(*tmpSolutionVec);
+    solution.scatterGlobalToLocal(*tmpSolutionVec);
   } // if
 
   const int numIntegrators = _integrators.size();
@@ -342,7 +342,7 @@
 
   // Update PETScVec of solution for changes to Lagrange multipliers.
   if (tmpSolutionVec) {
-    solution.scatterSectionToVector(*tmpSolutionVec);
+    solution.scatterLocalToGlobal(*tmpSolutionVec);
   } // if
 
   PYLITH_METHOD_END;
@@ -398,24 +398,24 @@
   writer.open(mesh, numTimeSteps);
    
   topology::Field& solution = _fields->solution();
-  solution.scatterVectorToSection(*solutionVec);
+  solution.scatterGlobalToLocal(*solutionVec);
   writer.writeVertexField(0.0, solution, mesh);
   solution.view("DIVERGED_SOLUTION");
   const char* label = solution.label();
 
   solution.label("solution_0");
-  solution.scatterVectorToSection(*solution0Vec);
+  solution.scatterGlobalToLocal(*solution0Vec);
   writer.writeVertexField(0.0, solution, mesh);
   solution.view("DIVERGED_SOLUTION0");
   solution.label(label);
 
   topology::Field& residual = _fields->get("residual");
-  residual.scatterVectorToSection(*residualVec);
+  residual.scatterGlobalToLocal(*residualVec);
   writer.writeVertexField(0.0, residual, mesh);
   residual.view("DIVERGED_RESIDUAL");
 
   residual.label("search_dir");
-  residual.scatterVectorToSection(*searchDirVec);
+  residual.scatterGlobalToLocal(*searchDirVec);
   writer.writeVertexField(0.0, residual, mesh);
   residual.view("DIVERGED_SEARCHDIR");
 

Modified: short/3D/PyLith/trunk/libsrc/pylith/problems/SolverLinear.cc
===================================================================
--- short/3D/PyLith/trunk/libsrc/pylith/problems/SolverLinear.cc	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/libsrc/pylith/problems/SolverLinear.cc	2013-07-11 20:48:27 UTC (rev 22569)
@@ -111,7 +111,7 @@
   _logger->eventBegin(scatterEvent);
 
   // Update PetscVector view of field.
-  residual.scatterSectionToVector();
+  residual.scatterLocalToGlobal();
 
   _logger->eventEnd(scatterEvent);
   _logger->eventBegin(setupEvent);
@@ -137,7 +137,7 @@
   _logger->eventBegin(scatterEvent);
 
   // Update section view of field.
-  solution->scatterVectorToSection();
+  solution->scatterGlobalToLocal();
 
   _logger->eventEnd(scatterEvent);
 

Modified: short/3D/PyLith/trunk/libsrc/pylith/problems/SolverNonlinear.cc
===================================================================
--- short/3D/PyLith/trunk/libsrc/pylith/problems/SolverNonlinear.cc	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/libsrc/pylith/problems/SolverNonlinear.cc	2013-07-11 20:48:27 UTC (rev 22569)
@@ -153,7 +153,7 @@
   _logger->eventBegin(scatterEvent);
 
   // Update section view of field.
-  solution->scatterVectorToSection();
+  solution->scatterGlobalToLocal();
 
   _logger->eventEnd(scatterEvent);
 

Modified: short/3D/PyLith/trunk/libsrc/pylith/topology/Field.cc
===================================================================
--- short/3D/PyLith/trunk/libsrc/pylith/topology/Field.cc	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/libsrc/pylith/topology/Field.cc	2013-07-11 20:48:27 UTC (rev 22569)
@@ -1113,24 +1113,24 @@
 // Scatter section information across processors to update the
 //  PETSc vector view of the field.
 void
-pylith::topology::Field::scatterSectionToVector(const char* context) const
-{ // scatterSectionToVector
+pylith::topology::Field::scatterLocalToGlobal(const char* context) const
+{ // scatterLocalToGlobal
   PYLITH_METHOD_BEGIN;
 
   assert(context);
   const ScatterInfo& sinfo = _getScatter(context);
-  scatterSectionToVector(sinfo.vector, context);
+  scatterLocalToGlobal(sinfo.vector, context);
 
   PYLITH_METHOD_END;
-} // scatterSectionToVector
+} // scatterLocalToGlobal
 
 // ----------------------------------------------------------------------
 // Scatter section information across processors to update the
 //  PETSc vector view of the field.
 void
-pylith::topology::Field::scatterSectionToVector(const PetscVec vector,
+pylith::topology::Field::scatterLocalToGlobal(const PetscVec vector,
 						const char* context) const
-{ // scatterSectionToVector
+{ // scatterLocalToGlobal
   PYLITH_METHOD_BEGIN;
 
   assert(vector);
@@ -1143,31 +1143,31 @@
   } // if
   
   PYLITH_METHOD_END;
-} // scatterSectionToVector
+} // scatterLocalToGlobal
 
 // ----------------------------------------------------------------------
 // Scatter PETSc vector information across processors to update the
 // section view of the field.
 void
-pylith::topology::Field::scatterVectorToSection(const char* context) const
-{ // scatterVectorToSection
+pylith::topology::Field::scatterGlobalToLocal(const char* context) const
+{ // scatterGlobalToLocal
   PYLITH_METHOD_BEGIN;
 
   assert(context);
 
   const ScatterInfo& sinfo = _getScatter(context);
-  scatterVectorToSection(sinfo.vector, context);
+  scatterGlobalToLocal(sinfo.vector, context);
 
   PYLITH_METHOD_END;
-} // scatterVectorToSection
+} // scatterGlobalToLocal
 
 // ----------------------------------------------------------------------
 // Scatter PETSc vector information across processors to update the
 // section view of the field.
 void
-pylith::topology::Field::scatterVectorToSection(const PetscVec vector,
-						const char* context) const
-{ // scatterVectorToSection
+pylith::topology::Field::scatterGlobalToLocal(const PetscVec vector,
+					      const char* context) const
+{ // scatterGlobalToLocal
   PYLITH_METHOD_BEGIN;
 
   assert(vector);
@@ -1181,7 +1181,7 @@
   } // if
 
   PYLITH_METHOD_END;
-} // scatterVectorToSection
+} // scatterGlobalToLocal
 
 // ----------------------------------------------------------------------
 // Get fiber dimension associated with section (only works if fiber

Modified: short/3D/PyLith/trunk/libsrc/pylith/topology/Field.hh
===================================================================
--- short/3D/PyLith/trunk/modulesrc/topology/Field.i	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/modulesrc/topology/Field.i	2013-07-11 20:48:27 UTC (rev 22569)
@@ -211,29 +211,37 @@
        */
       const PetscVec vector(const char* context ="") const;
 
-      /// Scatter section information across processors to update the
-      /// PETSc vector view of the field.
-      void scatterSectionToVector(const char* context ="") const;
-
       /** Scatter section information across processors to update the
-       * PETSc vector view of the field.
+       * global view of the field.
        *
-       * @param vector PETSc vector to update.
+       * @param context Label for context associated with vector.
        */
-      void scatterSectionToVector(const PetscVec vector,
-				  const char* context ="") const;
-
-      /// Scatter PETSc vector information across processors to update the
-      /// PETSc section view of the field.
-      void scatterVectorToSection(const char* context ="") const;
-
+      void scatterLocalToGlobal(const char* context ="") const;
+      
       /** Scatter section information across processors to update the
-       * PETSc vector view of the field.
+       * global view of the field.
        *
+       * @param vector PETSc vector to update.
+       * @param context Label for context associated with vector.
+       */
+      void scatterLocalToGlobal(const PetscVec vector,
+				const char* context ="") const;
+      
+      /** Scatter global information across processors to update the local
+       * view of the field.
+       *
+       * @param context Label for context associated with vector.
+       */
+      void scatterGlobalToLocal(const char* context ="") const;
+      
+      /** Scatter global information across processors to update the local
+       * view of the field.
+       *
        * @param vector PETSc vector used in update.
+       * @param context Label for context associated with vector.
        */
-      void scatterVectorToSection(const PetscVec vector,
-				  const char* context ="") const;
+      void scatterGlobalToLocal(const PetscVec vector,
+				const char* context ="") const;
 
     }; // Field
 

Modified: short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldMesh.cc
===================================================================
--- short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldMesh.cc	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldMesh.cc	2013-07-11 20:48:27 UTC (rev 22569)
@@ -1188,10 +1188,10 @@
 } // testVector
 
 // ----------------------------------------------------------------------
-// Test scatterSectionToVector().
+// Test scatterLocalToGlobal().
 void
-pylith::topology::TestFieldMesh::testScatterSectionToVector(void)
-{ // testScatterSectionToVector
+pylith::topology::TestFieldMesh::testScatterLocalToGlobal(void)
+{ // testScatterLocalToGlobal
   PYLITH_METHOD_BEGIN;
 
   const char* context = "abc";
@@ -1225,7 +1225,7 @@
   } // setup field
 
   field.createScatter(mesh, context);
-  field.scatterSectionToVector(context);
+  field.scatterLocalToGlobal(context);
 
   const PetscVec vec = field.vector(context);CPPUNIT_ASSERT(vec);
   PetscInt size = 0;
@@ -1241,13 +1241,13 @@
   err = VecRestoreArray(vec, &valuesVec);PYLITH_CHECK_ERROR(err);
 
   PYLITH_METHOD_END;
-} // testScatterSectionToVector
+} // testScatterLocalToGlobal
 
 // ----------------------------------------------------------------------
-// Test scatterVectorToSection().
+// Test scatterGlobalToLocal().
 void
-pylith::topology::TestFieldMesh::testScatterVectorToSection(void)
-{ // testScatterVectorToSection
+pylith::topology::TestFieldMesh::testScatterGlobalToLocal(void)
+{ // testScatterGlobalToLocal
   PYLITH_METHOD_BEGIN;
 
   const char* context = "abcd";
@@ -1283,7 +1283,7 @@
     valuesVec[i] = valuesE[i];
   err = VecRestoreArray(vec, &valuesVec);PYLITH_CHECK_ERROR(err);
 
-  field.scatterVectorToSection(context);
+  field.scatterGlobalToLocal(context);
 
   const PylithScalar tolerance = 1.0e-06;
   VecVisitorMesh fieldVisitor(field);
@@ -1297,7 +1297,7 @@
   } // for
 
   PYLITH_METHOD_END;
-} // testScatterVectorToSection
+} // testScatterGlobalToLocal
 
 // ----------------------------------------------------------------------
 // Test splitDefault().

Modified: short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldMesh.hh
===================================================================
--- short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldMesh.hh	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldMesh.hh	2013-07-11 20:48:27 UTC (rev 22569)
@@ -74,8 +74,8 @@
   CPPUNIT_TEST( testCreateScatter );
   CPPUNIT_TEST( testCreateScatterWithBC );
   CPPUNIT_TEST( testVector );
-  CPPUNIT_TEST( testScatterSectionToVector );
-  CPPUNIT_TEST( testScatterVectorToSection );
+  CPPUNIT_TEST( testScatterLocalToGlobal );
+  CPPUNIT_TEST( testScatterGlobalToLocal );
   CPPUNIT_TEST( testSplitDefault );
   CPPUNIT_TEST( testCloneSectionSplit );
 
@@ -171,11 +171,11 @@
   /// Test vector().
   void testVector(void);
 
-  /// Test scatterSectionToVector().
-  void testScatterSectionToVector(void);
+  /// Test scatterLocalToGlobal().
+  void testScatterLocalToGlobal(void);
 
-  /// Test scatterVectorToSection().
-  void testScatterVectorToSection(void);
+  /// Test scatterGlobalToLocal().
+  void testScatterGlobalToLocal(void);
 
   /// Test splitDefault().
   void testSplitDefault(void);

Modified: short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldSubMesh.cc
===================================================================
--- short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldSubMesh.cc	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldSubMesh.cc	2013-07-11 20:48:27 UTC (rev 22569)
@@ -874,10 +874,10 @@
 } // testVector
 
 // ----------------------------------------------------------------------
-// Test scatterSectionToVector().
+// Test scatterLocalToGlobal().
 void
-pylith::topology::TestFieldSubMesh::testScatterSectionToVector(void)
-{ // testScatterSectionToVector
+pylith::topology::TestFieldSubMesh::testScatterLocalToGlobal(void)
+{ // testScatterLocalToGlobal
   PYLITH_METHOD_BEGIN;
 
   const char* context = "abc";
@@ -912,7 +912,7 @@
   } // setup field
 
   field.createScatter(submesh, context);
-  field.scatterSectionToVector(context);
+  field.scatterLocalToGlobal(context);
 
   PetscErrorCode err = 0;
   const PetscVec vec = field.vector(context);CPPUNIT_ASSERT(vec);
@@ -929,13 +929,13 @@
   err = VecRestoreArray(vec, &valuesVec);PYLITH_CHECK_ERROR(err);
 
   PYLITH_METHOD_END;
-} // testScatterSectionToVector
+} // testScatterLocalToGlobal
 
 // ----------------------------------------------------------------------
-// Test scatterVectorToSection().
+// Test scatterGlobalToLocal().
 void
-pylith::topology::TestFieldSubMesh::testScatterVectorToSection(void)
-{ // testScatterVectorToSection
+pylith::topology::TestFieldSubMesh::testScatterGlobalToLocal(void)
+{ // testScatterGlobalToLocal
   PYLITH_METHOD_BEGIN;
 
   const char* context = "abcd";
@@ -971,7 +971,7 @@
     valuesVec[i] = valuesE[i];
   err = VecRestoreArray(vec, &valuesVec);PYLITH_CHECK_ERROR(err);
 
-  field.scatterVectorToSection(context);
+  field.scatterGlobalToLocal(context);
 
   const PylithScalar tolerance = 1.0e-06;
   VecVisitorMesh fieldVisitor(field);
@@ -986,7 +986,7 @@
 
 
   PYLITH_METHOD_END;
-} // testScatterVectorToSection
+} // testScatterGlobalToLocal
 
 // ----------------------------------------------------------------------
 void

Modified: short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldSubMesh.hh
===================================================================
--- short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldSubMesh.hh	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/unittests/libtests/topology/TestFieldSubMesh.hh	2013-07-11 20:48:27 UTC (rev 22569)
@@ -66,8 +66,8 @@
   CPPUNIT_TEST( testCreateScatter );
   CPPUNIT_TEST( testCreateScatterWithBC );
   CPPUNIT_TEST( testVector );
-  CPPUNIT_TEST( testScatterSectionToVector );
-  CPPUNIT_TEST( testScatterVectorToSection );
+  CPPUNIT_TEST( testScatterLocalToGlobal );
+  CPPUNIT_TEST( testScatterGlobalToLocal );
 
   CPPUNIT_TEST_SUITE_END();
 
@@ -134,11 +134,11 @@
   /// Test vector().
   void testVector(void);
 
-  /// Test scatterSectionToVector().
-  void testScatterSectionToVector(void);
+  /// Test scatterLocalToGlobal().
+  void testScatterLocalToGlobal(void);
 
-  /// Test scatterVectorToSection().
-  void testScatterVectorToSection(void);
+  /// Test scatterGlobalToLocal().
+  void testScatterGlobalToLocal(void);
 
 // PRIVATE METHODS /////////////////////////////////////////////////////
 private :



More information about the CIG-COMMITS mailing list
--- short/3D/PyLith/trunk/libsrc/pylith/topology/Field.hh	2013-07-11 19:41:57 UTC (rev 22568)
+++ short/3D/PyLith/trunk/libsrc/pylith/topology/Field.hh	2013-07-11 20:48:27 UTC (rev 22569)
@@ -403,29 +403,37 @@
    */
   const PetscVec vector(const char* context ="") const;
 
-  /// Scatter section information across processors to update the
-  /// PETSc vector view of the field.
-  void scatterSectionToVector(const char* context ="") const;
+  /** Scatter section information across processors to update the
+   * global view of the field.
+   *
+   * @param context Label for context associated with vector.
+   */
+  void scatterLocalToGlobal(const char* context ="") const;
 
   /** Scatter section information across processors to update the
    * PETSc vector view of the field.
    *
    * @param vector PETSc vector to update.
+   * @param context Label for context associated with vector.
    */
-  void scatterSectionToVector(const PetscVec vector,
-			      const char* context ="") const;
+  void scatterLocalToGlobal(const PetscVec vector,
+			    const char* context ="") const;
 
-  /// Scatter PETSc vector information across processors to update the
-  /// PETSc section view of the field.
-  void scatterVectorToSection(const char* context ="") const;
+  /** Scatter global information across processors to update the local
+   * view of the field.
+   *
+   * @param context Label for context associated with vector.
+   */
+  void scatterGlobalToLocal(const char* context ="") const;
 
   /** Scatter section information across processors to update the
    * PETSc vector view of the field.
    *
    * @param vector PETSc vector used in update.
+   * @param context Label for context associated with vector.
    */
-  void scatterVectorToSection(const PetscVec vector,
-			      const char* context ="") const;
+  void scatterGlobalToLocal(const PetscVec vector,
+			    const char* context ="") const;
 
 // PRIVATE STRUCTS //////////////////////////////////////////////////////
 private :
@@ -403,29 +403,37 @@
 
   /** Scatter section information across processors to update the
-   * PETSc vector view of the field.
+   * global view of the field.
    *
    * @param vector PETSc vector to update.
@@ -403,29 +403,37 @@
 
-  /** Scatter section information across processors to update the
-   * PETSc vector view of the field.
+  /** Scatter global information across processors to update the local
+   * view of the field.
    *
    * @param vector PETSc vector used in update.

Modified: short/3D/PyLith/trunk/modulesrc/topology/Field.i
===================================================================